<div align="center">

# KilleenGeo

<a href="https://pepy.tech/project/killeengeo">
<img src="https://pepy.tech/badge/killeengeo/month" alt="Downloads" />
</a>
<a href="https://github.com/benjamindkilleen/killeengeo/releases/">
<img src="https://img.shields.io/github/release/benjamindkilleen/killeengeo.svg" alt="GitHub release" />
</a>
<a href="https://pypi.org/project/killeengeo/">
<img src="https://img.shields.io/pypi/v/killeengeo" alt="PyPI" />
</a>
<a href="http://killeengeo.readthedocs.io/?badge=latest">
<img src="https://readthedocs.org/projects/killeengeo/badge/?version=latest" alt="Documentation Status" />
</a>
<a href="https://github.com/psf/black">
<img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black" />
</a>

</div>

2D and 3D geometry in Python. This library was originally a part of the
[DeepDRR](https://github.com/arcadelab/deepdrr) package, but has been split out into its own package
for easier use in other projects. It contains a lot of custom implementations with no overarching
design philosophy, other than getting me through my PhD.

## Installation

```bash
pip install killeengeo
```

## Usage

```python
import killeengeo as geo
```

## Documentation

Documentation is (maybe) available at [killeengeo.readthedocs.io](https://killeengeo.readthedocs.io/en/latest/).
